@@ -9,7 +9,7 @@ def delta2dict( delta ):
         'microsecond' : delta.microseconds
     }
 
-def human( delta, precision = 1 ):
+def delta2human( delta, precision = 2 ):
     """return human readable delta string"""
     units = ( 'year', 'day', 'hour', 'minute', 'second', 'microsecond' )
     d = delta2dict( delta )
@@ -23,6 +23,14 @@ def human( delta, precision = 1 ):
         count += 1
     return ', '.join( hlist )
 
+def human( d1, precision = 2 ):
+    """Pass datetime we will return human delta string"""
+    from datetime import datetime
+    d2 = datetime.now()
+    delta = d2 - d1
+    return delta2human( delta, precision ) 
+  
+
 def test():
     """Test and example usage"""
     from datetime import datetime
@@ -39,6 +47,7 @@ def test():
     delta = d2 - d1
     print 'This is just the ago.py test:'
     print delta2dict( delta )
-    print 'Commented ' + human( delta, 3 ) + ' ago'
+    print 'Commented ' + delta2human( delta, 3 ) + ' ago'
+    print 'Commented ' + human( d1 ) + ' ago'
 
 if __name__ == "__main__": test()
